/***************************************************************************
						gui3dview.h    -  description
							-------------------
	begin                : mar 22th, 2004
	copyright            : (C) 2004 by Duong-Khang NGUYEN
	email                : neoneurone @ users sourceforge net

	$Id: gui3dview.h 261 2007-10-20 18:22:47Z neoneurone $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   any later version.                                                    *
 *                                                                         *
 ***************************************************************************/

#if !defined(_OPENCITY_GUI3DVIEW_H_)
	#define _OPENCITY_GUI3DVIEW_H_ 1

	#include "main.h"
	#include "guimain.h"


   //========================================================================
   /** NOT implemented yet
   */
class GUI3DView : public GUIMain {
public:
	GUI3DView() {}
	virtual ~GUI3DView() {}

};

#endif































